# [DRF UTILS][docs]

[comment]: <> ([![Build Status]&#40;https://travis-ci.org/kenneth051/drf-history.svg?branch=develop&#41;]&#40;https://travis-ci.org/kenneth051/drf-history&#41;  [![Coverage Status]&#40;https://coveralls.io/repos/github/kenneth051/django-track-actions/badge.svg?branch=develop&#41;]&#40;https://coveralls.io/github/kenneth051/django-track-actions?branch=develop&#41;  [![Maintainability]&#40;https://api.codeclimate.com/v1/badges/fc8a5a15c480d2ad117d/maintainability&#41;]&#40;https://codeclimate.com/github/kenneth051/django-track-actions/maintainability&#41; [![Downloads]&#40;https://pepy.tech/badge/drf-safe-jack&#41;]&#40;https://pepy.tech/project/drf-safe-jack&#41;[![Downloads]&#40;https://pepy.tech/badge/drf-safe-jack/month&#41;]&#40;https://pepy.tech/project/drf-safe-jack&#41;[![Downloads]&#40;https://pepy.tech/badge/drf-safe-jack/week&#41;]&#40;https://pepy.tech/project/drf-history/week&#41; [![PyPI version]&#40;https://badge.fury.io/py/drf-safe-jack.svg&#41;]&#40;https://badge.fury.io/py/drf-safe-jack&#41;)



# 安装

```shell
pip install drf-custom-utils
```



# 功能

- ### DRF mixin 扩展(不分页返回数据action  单独设置model某个字段或做个字段值  基于action实现)

- ### 微信模板消息发送封装(提供相关小程序和公众号 AppID和secret以及模板消息ID配置在settings中)

- ### 与第三方对接相关请求封装

